<?php

# Pages config file for FitGallery 0.95
# under public domain

# In order to get specific configuration for some pages, you can copy
# this file under the name 'config-gals.php' (for galleries page [ver_gals.php])
# or 'config-exif.php' (for exif page [exif.php])

# Options suitable for config-pages.php and config-gal.php

$titulo='titulo';              # name of text/psuedoHTML-PHP files with galleries titles
$subtitulo='subtitulo';        # name of text/psuedoHTML-PHP files with galleries subtitles
$def_avance=12;                # number of thumbs per page by default if not specified by user
$max_avance=100;               # max number of thumbs per page allowed
$remote_espace=true;           # Espaces for remote old galleries (without number, size and date info)
$nav_pos='both';               # Navigator (go to pages number..) position ('top', 'bottom', 'both' or 'none')
$tpp_pos='both';               # Thumbnails per page form position ('top', 'bottom', 'both' or 'none')
$print_totals=true;            # Print total bytes at bottom

# Options suitable for config-pages.php, config-gal.php and config-exif.php

$style='random.css.php';       # Style sheet for pages
#$lang='es';                    # language, only support at this moment 'es' (spanish)
$lang='en';                    # and 'en' (english)
$charset='US-ASCII';           # charset used on pages, alternatives: ISO-8859-1, UTF-8
$date_string='Y-m-d H:i:s';    # Date format (php specification for date() function), ISO by default
$w3logo=true;                  # show W3C logo
$powered=true;                 # show 'powered by FitGallery' message

?>
